@@ -28,10 +28,11 @@ class MatchTypeError(Exception):
         return "规则 %s 对应的种类 %s 不受支持"%(self.rule,self.kind)
 
 class AdminRunError(Exception):
-    def __init__(self,api):
+    def __init__(self,api,detail):
         self.api  = api
+        self.detail = detail
     def __str__(self):
-        return "重载API映射 %s 出现错误\n可能原因:\n1.未注册映射\n2.重载映射出错"%self.api
+        return "重载API映射 %s 出现错误\n可能原因:\n1.未注册映射\n2.重载映射出错。\n详细原因:%s"%(self.api,self.detail)
 
 class AdminStyleError(Exception):
     def __init__(self,api):
