@@ -1,6 +1,7 @@
 from .models import CSVobjects,WriteCSVobject
 from datetime import datetime
 import csv,os
+from typing import Union
 
 class Operate():
 
@@ -25,10 +26,13 @@ class Operate():
             return CSVobjects(_content=_content_List_,_fileMessage=self.return_file_message(PATH))
 
 
-    def write(self,PATH:str,header:[],rows:[[]],Writing_method:str) -> WriteCSVobject:
+    def write(self,PATH:str,header:Union[list,bool],rows:[[]],Writing_method:str) -> WriteCSVobject:
         with open(PATH, Writing_method) as f:
             f_csv = csv.writer(f)
-            f_csv.writerow(header)
+            if type(header) == bool:
+                pass
+            else:
+                f_csv.writerow(header)
             f_csv.writerows(rows)
             # csv op is end
         return WriteCSVobject(_content=self.read(PATH, "r")._content,_fileMessage=self.return_file_message(PATH),_path=PATH)
