@@ -1,4 +1,4 @@
-import requests,os
+import requests
 from .models import TestResponse
 from typing import Union,Dict
 
